import { sequelize } from '../../../modules/sequelize.ts';
import { DataTypes, Model } from 'sequelize';

export interface PackagesData {}
export type PackagesPublish = {
  key: string;
  title?: string;
  description?: string;
  version?: string;
  filesName?: any[];
};
export type Packages = Partial<InstanceType<typeof PackagesModel>>;

/**
 * 用户代码容器
 */
export class PackagesModel extends Model {
  declare id: string;
  declare title: string;
  declare description: string;
  declare tags: string[];
  declare data: PackagesData; // files
  declare publish: PackagesPublish;
  declare uid: string;
  declare expand: any;
}
PackagesModel.init(
  {
    id: {
      type: DataTypes.UUID,
      primaryKey: true,
      defaultValue: DataTypes.UUIDV4,
      comment: 'id',
    },
    title: {
      type: DataTypes.TEXT,
      defaultValue: '',
    },
    description: {
      type: DataTypes.TEXT,
      defaultValue: '',
    },
    tags: {
      type: DataTypes.JSONB,
      defaultValue: [],
    },
    data: {
      type: DataTypes.JSONB,
      defaultValue: {},
    },
    publish: {
      type: DataTypes.JSONB,
      defaultValue: {},
    }, 
    expand: {
      type: DataTypes.JSONB,
      defaultValue: {},
    },
    uid: {
      type: DataTypes.UUID,
      allowNull: true,
    },
  },
  {
    sequelize,
    tableName: 'kv_packages',
    paranoid: true,
  },
);

PackagesModel.sync({ alter: true, logging: false }).catch((e) => {
  console.error('PackagesModel sync', e);
});
